#!/bin/sh
echo 'name: MissingH
version: 1.2.0.0
id: MissingH-1.2.0.0-802d843c83575108fd1ecf601b23d5ed

license: BSD3
copyright: Copyright (c) 2004-2011 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Beta
homepage: http://software.complete.org/missingh
package-url:
synopsis: Large utility library
description: MissingH is a library of all sorts of utility functions for
             Haskell programmers.  It is written in pure Haskell and thus should
             be extremely portable and easy to use.
category: Unclassified
author: John Goerzen
pkgpath: devel/hs-MissingH
exposed: True
exposed-modules: Data.String.Utils System.IO.Utils System.IO.Binary
                 Data.List.Utils System.Daemon Text.ParserCombinators.Parsec.Utils
                 Network.Email.Mailbox Control.Concurrent.Thread.Utils
                 Network.Email.Sendmail Data.CSV System.Cmd.Utils Data.BinPacking
                 Data.Progress.Tracker Data.Progress.Meter Data.Quantity
                 Data.Map.Utils System.Path System.Path.NameManip
                 System.Path.WildMatch System.Path.Glob System.Time.Utils
                 System.Time.ParseDate Network.Utils Network.SocketServer
                 Data.Either.Utils Data.Maybe.Utils Data.Tuple.Utils Data.Bits.Utils
                 Data.Hash.CRC32.Posix Data.Hash.CRC32.GZip Data.Hash.MD5
                 Data.Hash.MD5.Zord64_HARD Data.Compression.Inflate
                 System.FileArchive.GZip System.IO.HVFS System.IO.HVFS.Combinators
                 System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
                 System.IO.StatCompat System.IO.WindowsCompat System.IO.PlafCompat
                 System.Posix.Consts System.Debian System.Debian.ControlParser
                 Data.MIME.Types System.Console.GetOpt.Utils
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/MissingH-1.2.0.0
library-dirs: /usr/local/lib/ghc/MissingH-1.2.0.0
hs-libraries: HSMissingH-1.2.0.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: HUnit-1.2.5.2-6e02ecc15e3cc5ab8ef10df50d05a1a9
         array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
         base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
         directory-1.2.0.1-ee04c884b72040489d2e2ca6dd62e6ac
         filepath-1.3.0.1-b12cbe18566fe1532a1fda4c85e31cbe
         hslogger-1.2.1-4c18aebfb9eaa2568b8e99aa6298aede
         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
         network-2.4.1.2-2410fd33cfc22dd877d4b24516181434
         old-locale-1.0.0.5-6729cb9d9cc62d150655de8fc5401b91
         old-time-1.1.0.1-029c40e673a46f6084b935f654a6fa28
         parsec-3.1.3-8bc25b86282839a5b5fcb3c428bb3b9c
         process-1.1.0.2-76e05340eb66705981411022731ca84a
         random-1.0.1.1-023a342365721422ffd5a919bc8708bb
         regex-compat-0.95.1-5aa32e2bfd54140cd88d19d49933a997
         time-1.4.0.1-10dc4804a19dc0000fab79908f1a9f50
         unix-2.6.0.1-2939d4be83b53d31ca104e0487b1ef98
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-MissingH-1.2.0.0/html/MissingH.haddock
haddock-html: /usr/local/share/doc/hs-MissingH-1.2.0.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
